@@ -258,9 +258,10 @@ struct activity io_act = {
 	.f_render	= render_io_stats,
 	.f_xml_print	= xml_print_io_stats,
 	.f_json_print	= json_print_io_stats,
+	.f_svg_print	= svg_print_io_stats,
 	.hdr_line	= "tps;rtps;wtps;bread/s;bwrtn/s",
 	.name		= "A_IO",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -327,9 +328,10 @@ struct activity ktables_act = {
 	.f_render	= render_ktables_stats,
 	.f_xml_print	= xml_print_ktables_stats,
 	.f_json_print	= json_print_ktables_stats,
+	.f_svg_print	= svg_print_ktables_stats,
 	.hdr_line	= "dentunusd;file-nr;inode-nr;pty-nr",
 	.name		= "A_KTABLES",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -444,7 +446,7 @@ struct activity disk_act = {
 /* Network interfaces activity */
 struct activity net_dev_act = {
 	.id		= A_NET_DEV,
-	.options	= AO_COLLECTED | AO_GRAPH_PER_ITEM,
+	.options	= AO_COLLECTED + AO_GRAPH_PER_ITEM,
 	.magic		= ACTIVITY_MAGIC_BASE + 2,
 	.group		= G_DEFAULT,
 #ifdef SOURCE_SADC
@@ -595,9 +597,10 @@ struct activity net_sock_act = {
 	.f_render	= render_net_sock_stats,
 	.f_xml_print	= xml_print_net_sock_stats,
 	.f_json_print	= json_print_net_sock_stats,
+	.f_svg_print	= svg_print_net_sock_stats,
 	.hdr_line	= "totsck;tcpsck;udpsck;rawsck;ip-frag;tcp-tw",
 	.name		= "A_NET_SOCK",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -628,9 +631,10 @@ struct activity net_ip_act = {
 	.f_render	= render_net_ip_stats,
 	.f_xml_print	= xml_print_net_ip_stats,
 	.f_json_print	= json_print_net_ip_stats,
+	.f_svg_print	= svg_print_net_ip_stats,
 	.hdr_line	= "irec/s;fwddgm/s;idel/s;orq/s;asmrq/s;asmok/s;fragok/s;fragcrt/s",
 	.name		= "A_NET_IP",
-	.g_nr		= 0,
+	.g_nr		= 3,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -762,9 +766,10 @@ struct activity net_tcp_act = {
 	.f_render	= render_net_tcp_stats,
 	.f_xml_print	= xml_print_net_tcp_stats,
 	.f_json_print	= json_print_net_tcp_stats,
+	.f_svg_print	= svg_print_net_tcp_stats,
 	.hdr_line	= "active/s;passive/s;iseg/s;oseg/s",
 	.name		= "A_NET_TCP",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -828,9 +833,10 @@ struct activity net_udp_act = {
 	.f_render	= render_net_udp_stats,
 	.f_xml_print	= xml_print_net_udp_stats,
 	.f_json_print	= json_print_net_udp_stats,
+	.f_svg_print	= svg_print_net_udp_stats,
 	.hdr_line	= "idgm/s;odgm/s;noport/s;idgmerr/s",
 	.name		= "A_NET_UDP",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -861,9 +867,10 @@ struct activity net_sock6_act = {
 	.f_render	= render_net_sock6_stats,
 	.f_xml_print	= xml_print_net_sock6_stats,
 	.f_json_print	= json_print_net_sock6_stats,
+	.f_svg_print	= svg_print_net_sock6_stats,
 	.hdr_line	= "tcp6sck;udp6sck;raw6sck;ip6-frag",
 	.name		= "A_NET_SOCK6",
-	.g_nr		= 0,
+	.g_nr		= 1,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
@@ -1082,7 +1089,7 @@ struct activity pwr_cpufreq_act = {
 /* Fan */
 struct activity pwr_fan_act = {
 	.id		= A_PWR_FAN,
-	.options	= AO_NULL,
+	.options	= AO_GRAPH_PER_ITEM,
 	.magic		= ACTIVITY_MAGIC_BASE,
 	.group		= G_POWER,
 #ifdef SOURCE_SADC
@@ -1098,9 +1105,10 @@ struct activity pwr_fan_act = {
 	.f_render	= render_pwr_fan_stats,
 	.f_xml_print	= xml_print_pwr_fan_stats,
 	.f_json_print	= json_print_pwr_fan_stats,
+	.f_svg_print	= svg_print_pwr_fan_stats,
 	.hdr_line	= "FAN;DEVICE;rpm;drpm",
 	.name		= "A_PWR_FAN",
-	.g_nr		= 0,
+	.g_nr		= 1,
 #endif
 	.nr		= -1,
 	.nr2		= 1,
@@ -1115,7 +1123,7 @@ struct activity pwr_fan_act = {
 /* Temperature */
 struct activity pwr_temp_act = {
 	.id		= A_PWR_TEMP,
-	.options	= AO_NULL,
+	.options	= AO_GRAPH_PER_ITEM,
 	.magic		= ACTIVITY_MAGIC_BASE,
 	.group		= G_POWER,
 #ifdef SOURCE_SADC
@@ -1131,9 +1139,10 @@ struct activity pwr_temp_act = {
 	.f_render	= render_pwr_temp_stats,
 	.f_xml_print	= xml_print_pwr_temp_stats,
 	.f_json_print	= json_print_pwr_temp_stats,
+	.f_svg_print	= svg_print_pwr_temp_stats,
 	.hdr_line	= "TEMP;DEVICE;degC;%temp",
 	.name		= "A_PWR_TEMP",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= -1,
 	.nr2		= 1,
@@ -1197,9 +1206,10 @@ struct activity huge_act = {
 	.f_render	= render_huge_stats,
 	.f_xml_print	= xml_print_huge_stats,
 	.f_json_print	= json_print_huge_stats,
+	.f_svg_print	= svg_print_huge_stats,
 	.hdr_line	= "kbhugfree;kbhugused;%hugused",
 	.name		= "A_HUGE",
-	.g_nr		= 0,
+	.g_nr		= 2,
 #endif
 	.nr		= 1,
 	.nr2		= 1,
