@@ -88,7 +88,8 @@ void usage(char *progname)
 
 	fprintf(stderr, _("Options are:\n"
 			  "[ -C ] [ -c | -d | -g | -j | -p | -x ] [ -H ] [ -h ] [ -T | -t | -U ] [ -V ]\n"
-			  "[ -P { <cpu> [,...] | ALL } ] [ -s [ <hh:mm[:ss]> ] ] [ -e [ <hh:mm[:ss]> ] ]\n"
+			  "[ -O <opts> [,...] ] [ -P { <cpu> [,...] | ALL } ]\n"
+			  "[ -s [ <hh:mm[:ss]> ] ] [ -e [ <hh:mm[:ss]> ] ]\n"
 			  "[ -- <sar_options> ]\n"));
 	exit(1);
 }
@@ -1436,6 +1437,7 @@ int main(int argc, char **argv)
 	int day_offset = 0;
 	int i, rc;
 	char dfile[MAX_FILE_LEN];
+	char *t;
 
 	/* Get HZ */
 	get_HZ();
@@ -1492,6 +1494,25 @@ int main(int argc, char **argv)
 			}
 		}
 
+		else if (!strcmp(argv[opt], "-O")) {
+			/* Parse SVG options */
+			if (!argv[++opt] || sar_options) {
+				usage(argv[0]);
+			}
+			for (t = strtok(argv[opt], ","); t; t = strtok(NULL, ",")) {
+				if (!strcmp(t, K_SKIP_EMPTY)) {
+					flags |= S_F_SVG_SKIP;
+				}
+				else if (!strcmp(t, K_AUTOSCALE)) {
+					flags |= S_F_SVG_AUTOSCALE;
+				}
+				else {
+					usage(argv[0]);
+				}
+			}
+			opt++;
+		}
+
 		else if ((strlen(argv[opt]) > 1) &&
 			 (strlen(argv[opt]) < 4) &&
 			 !strncmp(argv[opt], "-", 1) &&
