@@ -157,7 +157,7 @@ void save_extrema(int llu_nr, int lu_nr, int u_nr, void *cs, void *ps,
 /*
  ***************************************************************************
  * Find the min and max values of all the graphs that will be drawn in the
- * same window. The graphs have their own min and max values in
+ * same view. The graphs have their own min and max values in
  * minv[pos...pos+n-1] and maxv[pos...pos+n-1]. 
  *
  * IN:
@@ -167,20 +167,23 @@ void save_extrema(int llu_nr, int lu_nr, int u_nr, void *cs, void *ps,
  * @maxv	Array containing max values for graphs.
  *
  * OUT:
- * @minv	minv[pos] is modified and contains the global min value found.
- * @maxv	maxv[pos] is modified and contains the global max value found.
+ * @gmin	Global min value found.
+ * @gmax	Global max value found.
  ***************************************************************************
  */
-void get_global_extrema(int pos, int n, double minv[], double maxv[])
+void get_global_extrema(int pos, int n, double minv[], double maxv[], double *gmin, double *gmax)
 {
 	int i;
 
+	*gmin = minv[pos];
+	*gmax = maxv[pos];
+
 	for (i = 1; i < n; i++) {
-		if (minv[pos + i] < minv[pos]) {
-			minv[pos] = minv[pos + i];
+		if (minv[pos + i] < *gmin) {
+			*gmin = minv[pos + i];
 		}
-		if (maxv[pos + i] > maxv[pos]) {
-			maxv[pos] = maxv[pos + i];
+		if (maxv[pos + i] > *gmax) {
+			*gmax = maxv[pos + i];
 		}
 	}
 }
@@ -495,6 +498,29 @@ void recappend(unsigned long timetag, double p_value, double value, char **out,
 	save_svg_data(data, out, outsize);
 }
 
+/*
+ ***************************************************************************
+ * Calculate 10 raised to the power of n.
+ *
+ * IN:
+ * @n	Power number to use.
+ *
+ * RETURNS:
+ * 10 raised to the power of n.
+ ***************************************************************************
+ */
+unsigned int pwr10(int n)
+{
+	int i;
+	unsigned int e = 1;
+
+	for (i = 0; i < n; i++) {
+		e = e * 10;
+	}
+
+	return e;
+}
+
 /*
  ***************************************************************************
  * Calculate the value on the Y axis between two horizontal lines that will
@@ -513,7 +539,8 @@ void recappend(unsigned long timetag, double p_value, double value, char **out,
 double ygrid(double lmax, int *dp)
 {
 	char val[32];
-	int l, i, e = 1;
+	int l;
+	unsigned int e;
 	long n = 0;
 
 	*dp = 0;
@@ -530,9 +557,8 @@ double ygrid(double lmax, int *dp)
 	l = strlen(val);
 	if (l < 2)
 		return n;
-	for (i = 1; i < l; i++) {
-		e = e * 10;
-	}
+	e = pwr10(l - 1);
+
 	return ((double) (((long) (n / e)) * e));
 }
 
@@ -589,7 +615,7 @@ void free_graphs(char **out, int *outsize, double *spmin, double *spmax)
  * Display all graphs for current activity.
  *
  * IN:
- * @g_nr	Number of graphs to display.
+ * @g_nr	Number of sets of graphs (views) to display.
  * @g_type	Type of graph (SVG_LINE_GRAPH, SVG_BAR_GRAPH).
  * @title	Titles for each set of graphs.
  * @g_title	Titles for each graph.
@@ -612,10 +638,11 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 	struct record_header stamp;
 	struct tm rectime;
 	char *out_p;
-	int i, j, dp, pos = 0;
+	int i, j, dp, pos = 0, views_nr = 0;
+	unsigned int asfactor[16];
 	long int k;
-	double lmax, xfactor, yfactor, ypos;
-	char cur_time[32];
+	double lmax, xfactor, yfactor, ypos, gmin, gmax;
+	char cur_time[32], val[32];
 
 	/* Translate to proper position for current activity */
 	printf("<g id=\"g%d\" transform=\"translate(0,%d)\">\n",
@@ -625,6 +652,15 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 	/* For each set of graphs which are part of current activity */
 	for (i = 0; i < g_nr; i++) {
 
+		/* Get global min and max value for current set of graphs */
+		get_global_extrema(pos, group[i], spmin, spmax, &gmin, &gmax);
+
+		/* Don't display empty views if requested */
+		if (SKIP_EMPTY_VIEWS(flags) && (gmax < 0.005))
+			continue;
+		/* Increment number of views actually displayed */
+		views_nr++;
+
 		/* Graph background */
 		printf("<rect x=\"0\" y=\"%d\" height=\"%d\" width=\"%d\"/>\n",
 		       i * SVG_T_YSIZE,
@@ -647,7 +683,7 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 		 * And a min and max value should have been found.
 		 */
 		if ((record_hdr->ust_time == svg_p->record_hdr->ust_time) ||
-		    (*(spmin + i) == DBL_MAX) || (*(spmax + i) == -DBL_MIN)) {
+		    (*(spmin + pos) == DBL_MAX) || (*(spmax + pos) == -DBL_MIN)) {
 			/* No data found */
 			printf("<text x=\"0\" y=\"%d\" style=\"fill: red; stroke: none\">No data</text>\n",
 			       SVG_M_YSIZE + i * SVG_T_YSIZE);
@@ -660,20 +696,38 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 		       SVG_M_XSIZE, SVG_M_YSIZE + SVG_G_YSIZE + i * SVG_T_YSIZE,
 		       SVG_M_XSIZE + SVG_G_XSIZE, SVG_M_YSIZE + SVG_G_YSIZE + i * SVG_T_YSIZE);
 
+		for (j = 0; j < 16; j++) {
+			/* Init autoscale factors */
+			asfactor[j] = 1;
+		}
+
+		if (AUTOSCALE_ON(flags) && (group[i] > 1) && gmax && (g_type == SVG_LINE_GRAPH)) {
+			/* Autoscaling... */
+			for (j = 0; (j < group[i]) && (j < 16); j++) {
+				if (!*(spmax + pos + j) || (*(spmax + pos + j) == gmax))
+					continue;
+
+				snprintf(val, 32, "%u", (unsigned int) (gmax / *(spmax + pos + j)));
+				if (strlen(val) > 0) {
+					asfactor[j] = pwr10(strlen(val) - 1);
+				}
+			}
+		}
+
 		/* Caption */
 		for (j = 0; j < group[i]; j++) {
 			/* Set dp to TRUE (1) if current metric is based on integer values */
 			dp = (g_title[pos + j][0] == '~');
+			snprintf(val, 32, "x%u ", asfactor[j]);
 			printf("<text x=\"%d\" y=\"%d\" style=\"fill: #%06x; stroke: none; font-size: 12px\">"
-			       "%s (%.*f, %.*f)</text>\n",
+			       "%s %s(%.*f, %.*f)</text>\n",
 			       5 + SVG_M_XSIZE + SVG_G_XSIZE, SVG_M_YSIZE + i * SVG_T_YSIZE + j * 15,
 			       svg_colors[(pos + j) & SVG_COLORS_IDX_MASK], g_title[pos + j] + dp,
-			       !dp * 2, *(spmin + pos + j), !dp * 2, *(spmax + pos + j));
+			       asfactor[j] == 1 ? "" : val,
+			       !dp * 2, *(spmin + pos + j) * asfactor[j],
+			       !dp * 2, *(spmax + pos + j) * asfactor[j]);
 		}
 
-		/* Get global min and max value for current set of graphs */
-		get_global_extrema(pos, group[i], spmin, spmax);
-
 		/* Translate to proper position for current graph within current activity */
 		printf("<g transform=\"translate(%d,%d)\">\n",
 		       SVG_M_XSIZE, SVG_M_YSIZE + SVG_G_YSIZE + i * SVG_T_YSIZE);
@@ -681,12 +735,12 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 		/* Grid */
 		if (g_type == SVG_LINE_GRAPH) {
 			/* For line graphs */
-			if (*(spmax + pos) == 0) {
+			if (!gmax) {
 				/* If all values are zero then set current max value to 1 */
 				lmax = 1.0;
 			}
 			else {
-				lmax = *(spmax + pos);
+				lmax = gmax;
 			}
 			/* Max value cannot be too small, else Y graduations will be meaningless */
 			if (lmax < SVG_H_GRIDNR * 0.01) {
@@ -700,8 +754,8 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 			dp = 0;		/* No decimals */
 
 			/* Max should be always 100% except for percentage values greater than 100% */
-			if (*(spmax + pos) > 100.0) {
-				lmax = *(spmax + pos);
+			if (gmax > 100.0) {
+				lmax = gmax;
 			}
 			else {
 				lmax = 100.0;
@@ -756,7 +810,7 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 				       svg_p->graph_no, pos + j, out_p,
 				       svg_colors[(pos + j) & SVG_COLORS_IDX_MASK],
 				       xfactor,
-				       yfactor);
+				       yfactor * asfactor[j]);
 			}
 			else if (*out_p) {	/* Ignore flat bars */
 				/* Bar graphs */
@@ -773,12 +827,12 @@ void draw_activity_graphs(int g_nr, int g_type, char *title[], char *g_title[],
 	printf("</g>\n");
 
 	/* Next graph */
-	(svg_p->graph_no) += g_nr;
+	(svg_p->graph_no) += views_nr;
 }
 
 /*
  ***************************************************************************
- * Display CPU statistics in SVG
+ * Display CPU statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1038,7 +1092,7 @@ __print_funct_t svg_print_cpu_stats(struct activity *a, int curr, int action, st
 
 /*
  ***************************************************************************
- * Display task creation and context switch statistics in SVG
+ * Display task creation and context switch statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1099,7 +1153,7 @@ __print_funct_t svg_print_pcsw_stats(struct activity *a, int curr, int action, s
 
 /*
  ***************************************************************************
- * Display swap statistics in SVG
+ * Display swap statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1114,7 +1168,7 @@ __print_funct_t svg_print_pcsw_stats(struct activity *a, int curr, int action, s
  ***************************************************************************
  */
 __print_funct_t svg_print_swap_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
-				       unsigned long long itv, struct record_header *record_hdr)
+				     unsigned long long itv, struct record_header *record_hdr)
 {
 	struct stats_swap
 		*ssc = (struct stats_swap *) a->buf[curr],
@@ -1159,7 +1213,7 @@ __print_funct_t svg_print_swap_stats(struct activity *a, int curr, int action, s
 
 /*
  ***************************************************************************
- * Display paging statistics in SVG
+ * Display paging statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1243,6 +1297,80 @@ __print_funct_t svg_print_paging_stats(struct activity *a, int curr, int action,
 	}
 }
 
+/*
+ ***************************************************************************
+ * Display I/O and transfer rate statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_io_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+				   unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_io
+		*sic = (struct stats_io *) a->buf[curr],
+		*sip = (struct stats_io *) a->buf[!curr];
+	int group[] = {3, 2};
+	char *title[] = {"I/O and transfer rate statistics (1)", "I/O and transfer rate statistics (2)"};
+	char *g_title[] = {"tps", "rtps", "wtps",
+			   "bread/s", "bwrtn/s"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(5, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 5, 0, (void *) a->buf[curr], (void *) a->buf[!curr],
+			     itv, spmin, spmax);
+
+		/* tps */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sip->dk_drive, sic->dk_drive, itv),
+			 out, outsize, svg_p->restart);
+		/* rtps */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sip->dk_drive_rio,  sic->dk_drive_rio, itv),
+			 out + 1, outsize + 1, svg_p->restart);
+		/* wtps */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sip->dk_drive_wio,  sic->dk_drive_wio, itv),
+			 out + 2, outsize + 2, svg_p->restart);
+		/* bread/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sip->dk_drive_rblk, sic->dk_drive_rblk, itv),
+			 out + 3, outsize + 3, svg_p->restart);
+		/* bwrtn/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sip->dk_drive_wblk, sic->dk_drive_wblk, itv),
+			 out + 4, outsize + 4, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
 /*
  ***************************************************************************
  * Display memory statistics in SVG.
@@ -1484,7 +1612,75 @@ __print_funct_t svg_print_memory_stats(struct activity *a, int curr, int action,
 
 /*
  ***************************************************************************
- * Display queue and load statistics in SVG
+ * Display kernel tables statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_ktables_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_ktables
+		*skc = (struct stats_ktables *) a->buf[curr];
+	int group[] = {3, 1};
+	char *title[] = {"Kernel tables (1)", "Kernel tables (2)"};
+	char *g_title[] = {"~file-nr", "~inode-nr", "~dentunusd",
+			   "~pty-nr"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(4, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 0, 4, (void *) a->buf[curr], NULL,
+			     itv, spmin, spmax);
+		/* file-nr */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) skc->file_used,
+			  out, outsize, svg_p->restart);
+		/* inode-nr */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) skc->inode_used,
+			  out + 1, outsize + 1, svg_p->restart);
+		/* dentunusd */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) skc->dentry_stat,
+			  out + 2, outsize + 2, svg_p->restart);
+		/* pty-nr */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) skc->pty_nr,
+			  out + 3, outsize + 3, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display queue and load statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1566,7 +1762,7 @@ __print_funct_t svg_print_queue_stats(struct activity *a, int curr, int action,
 
 /*
  ***************************************************************************
- * Display network interfaces statistics in SVG
+ * Display network interfaces statistics in SVG.
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1770,6 +1966,376 @@ __print_funct_t svg_print_net_dev_stats(struct activity *a, int curr, int action
 	}
 }
 
+/*
+ ***************************************************************************
+ * Display network socket statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_net_sock_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					 unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_net_sock
+		*snsc = (struct stats_net_sock *) a->buf[curr];
+	int group[] = {1, 5};
+	char *title[] = {"Network sockets (1)", "Network sockets (2)"};
+	char *g_title[] = {"~totsck",
+			   "~tcpsck", "~tcp-tw", "~udpsck", "~rawsck", "~ip-frag"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(6, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 0, 6, (void *) a->buf[curr], NULL,
+			     itv, spmin, spmax);
+		/* totsck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->sock_inuse,
+			  out, outsize, svg_p->restart);
+		/* tcpsck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->tcp_inuse,
+			  out + 1, outsize + 1, svg_p->restart);
+		/* tcp-tw */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->tcp_tw,
+			  out + 2, outsize + 2, svg_p->restart);
+		/* udpsck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->udp_inuse,
+			  out + 3, outsize + 3, svg_p->restart);
+		/* rawsck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->raw_inuse,
+			  out + 4, outsize + 4, svg_p->restart);
+		/* ip-frag */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->frag_inuse,
+			  out + 5, outsize + 5, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display IPv4 network statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_net_ip_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+				       unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_net_ip
+		*snic = (struct stats_net_ip *) a->buf[curr],
+		*snip = (struct stats_net_ip *) a->buf[!curr];
+	int group[] = {4, 2, 2};
+	char *title[] = {"IPv4 network statistics (1)", "IPv4 network statistics (2)", "IPv4 network statistics (3)"};
+	char *g_title[] = {"irec/s", "fwddgm/s", "idel/s", "orq/s",
+			   "asmrq/s", "asmok/s",
+			   "fragok/s", "fragcrt/s"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(8, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(8, 0, 0, (void *) a->buf[curr], (void *) a->buf[!curr],
+			     itv, spmin, spmax);
+
+		/* irec/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->InReceives, snic->InReceives, itv),
+			 out, outsize, svg_p->restart);
+		/* fwddgm/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->ForwDatagrams, snic->ForwDatagrams, itv),
+			 out + 1, outsize + 1, svg_p->restart);
+		/* idel/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->InDelivers, snic->InDelivers, itv),
+			 out + 2, outsize + 2, svg_p->restart);
+		/* orq/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->OutRequests, snic->OutRequests, itv),
+			 out + 3, outsize + 3, svg_p->restart);
+		/* asmrq/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->ReasmReqds, snic->ReasmReqds, itv),
+			 out + 4, outsize + 4, svg_p->restart);
+		/* asmok/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->ReasmOKs, snic->ReasmOKs, itv),
+			 out + 5, outsize + 5, svg_p->restart);
+		/* fragok/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->FragOKs, snic->FragOKs, itv),
+			 out + 6, outsize + 6, svg_p->restart);
+		/* fragcrt/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snip->FragCreates, snic->FragCreates, itv),
+			 out + 7, outsize + 7, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display TCPv4 network statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_net_tcp_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_net_tcp
+		*sntc = (struct stats_net_tcp *) a->buf[curr],
+		*sntp = (struct stats_net_tcp *) a->buf[!curr];
+	int group[] = {2, 2};
+	char *title[] = {"TCPv4 network statistics (1)", "TCPv4 network statistics (2)"};
+	char *g_title[] = {"active/s", "passive/s",
+			   "iseg/s", "oseg/s"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(4, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 4, 0, (void *) a->buf[curr], (void *) a->buf[!curr],
+			     itv, spmin, spmax);
+
+		/* active/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sntp->ActiveOpens, sntc->ActiveOpens, itv),
+			 out, outsize, svg_p->restart);
+		/* passive/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sntp->PassiveOpens, sntc->PassiveOpens, itv),
+			 out + 1, outsize + 1, svg_p->restart);
+		/* iseg/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sntp->InSegs, sntc->InSegs, itv),
+			 out + 2, outsize + 2, svg_p->restart);
+		/* oseg/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(sntp->OutSegs, sntc->OutSegs, itv),
+			 out + 3, outsize + 3, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display UDPv4 network statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_net_udp_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_net_udp
+		*snuc = (struct stats_net_udp *) a->buf[curr],
+		*snup = (struct stats_net_udp *) a->buf[!curr];
+	int group[] = {2, 2};
+	char *title[] = {"UDPv4 network statistics (1)", "UDPv4 network statistics (2)"};
+	char *g_title[] = {"idgm/s", "odgm/s",
+			   "noport/s", "idgmerr/s"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(4, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 4, 0, (void *) a->buf[curr], (void *) a->buf[!curr],
+			     itv, spmin, spmax);
+
+		/* idgm/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snup->InDatagrams, snuc->InDatagrams, itv),
+			 out, outsize, svg_p->restart);
+		/* odgm/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snup->OutDatagrams, snuc->OutDatagrams, itv),
+			 out + 1, outsize + 1, svg_p->restart);
+		/* noport/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snup->NoPorts, snuc->NoPorts, itv),
+			 out + 2, outsize + 2, svg_p->restart);
+		/* idgmerr/s */
+		lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 S_VALUE(snup->InErrors, snuc->InErrors, itv),
+			 out + 3, outsize + 3, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display IPV6 network socket statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_net_sock6_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					  unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_net_sock6
+		*snsc = (struct stats_net_sock6 *) a->buf[curr];
+	int group[] = {4};
+	char *title[] = {"IPv6 network sockets"};
+	char *g_title[] = {"~tcp6sck", "~udp6sck", "~raw6sck", "~ip6-frag"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(4, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 0, 4, (void *) a->buf[curr], NULL,
+			     itv, spmin, spmax);
+		/* tcp6sck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->tcp6_inuse,
+			  out, outsize, svg_p->restart);
+		/* udp6sck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->udp6_inuse,
+			  out + 1, outsize + 1, svg_p->restart);
+		/* raw6sck */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->raw6_inuse,
+			  out + 2, outsize + 2, svg_p->restart);
+		/* ip6-frag */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) snsc->frag6_inuse,
+			  out + 3, outsize + 3, svg_p->restart);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH, title, g_title, NULL, group,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
 /*
  ***************************************************************************
  * Display CPU frequency statistics in SVG.
@@ -1854,3 +2420,260 @@ __print_funct_t svg_print_pwr_cpufreq_stats(struct activity *a, int curr, int ac
 		free_graphs(out, outsize, spmin, spmax);
 	}
 }
+
+/*
+ ***************************************************************************
+ * Display fan statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_pwr_fan_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					unsigned long long g_itv, struct record_header *record_hdr)
+{
+	struct stats_pwr_fan *spc, *spp;
+	int group[] = {1};
+	char *title[] = {"Fan speed"};
+	char *g_title[] = {"~rpm"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+	char item_name[MAX_SENSORS_DEV_LEN + 8];
+	int i;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(a->nr, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* For each fan */
+		for (i = 0; i < a->nr; i++) {
+
+			spc = (struct stats_pwr_fan *) ((char *) a->buf[curr]  + i * a->msize);
+			spp = (struct stats_pwr_fan *) ((char *) a->buf[!curr]  + i * a->msize);
+
+			/* rpm */
+			recappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+				  (double) spp->rpm,
+				  (double) spc->rpm,
+				  out + i, outsize + i, svg_p->restart, svg_p->dt,
+				  spmin + i, spmax + i);
+		}
+	}
+
+	if (action & F_END) {
+		for (i = 0; i < a->nr; i++) {
+
+			spc = (struct stats_pwr_fan *) ((char *) a->buf[curr]  + i * a->msize);
+
+			snprintf(item_name, MAX_SENSORS_DEV_LEN + 8, "%d: %s", i + 1, spc->device);
+			item_name[MAX_SENSORS_DEV_LEN + 7] = '\0';
+
+			draw_activity_graphs(a->g_nr, SVG_LINE_GRAPH,
+					     title, g_title, item_name, group,
+					     spmin + i, spmax + i, out + i, outsize + i,
+					     svg_p, record_hdr);
+		}
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display temperature statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_pwr_temp_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+					 unsigned long long g_itv, struct record_header *record_hdr)
+{
+	struct stats_pwr_temp *spc;
+	int group[] = {1};
+	char *title1[] = {"Device temperature (1)"};
+	char *title2[] = {"Device temperature (2)"};
+	char *g1_title[] = {"~degC"};
+	char *g2_title[] = {"%temp"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+	char item_name[MAX_SENSORS_DEV_LEN + 8];
+	int i;
+	double tval;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(2 * a->nr, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* For each temperature  sensor */
+		for (i = 0; i < a->nr; i++) {
+
+			spc = (struct stats_pwr_temp *) ((char *) a->buf[curr]  + i * a->msize);
+
+			/* Look for min/max values */
+			if (spc->temp < *(spmin + 2 * i)) {
+				*(spmin + 2 * i) = spc->temp;
+			}
+			if (spc->temp > *(spmax + 2 * i)) {
+				*(spmax + 2 * i) = spc->temp;
+			}
+			tval = (spc->temp_max - spc->temp_min) ?
+			       (spc->temp - spc->temp_min) / (spc->temp_max - spc->temp_min) * 100 :
+			       0.0;
+			if (tval < *(spmin + 2 * i + 1)) {
+				*(spmin + 2 * i + 1) = tval;
+			}
+			if (tval > *(spmax + 2 * i + 1)) {
+				*(spmax + 2 * i + 1) = tval;
+			}
+
+			/* degC */
+			lnappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+				 (double) spc->temp,
+				 out + 2 * i, outsize + 2 * i, svg_p->restart);
+			/* %temp */
+			brappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+				 0.0, tval,
+				 out + 2 * i + 1, outsize + 2 * i + 1, svg_p->dt);
+		}
+	}
+
+	if (action & F_END) {
+		for (i = 0; i < a->nr; i++) {
+
+			spc = (struct stats_pwr_temp *) ((char *) a->buf[curr]  + i * a->msize);
+
+			snprintf(item_name, MAX_SENSORS_DEV_LEN + 8, "%d: %s", i + 1, spc->device);
+			item_name[MAX_SENSORS_DEV_LEN + 7] = '\0';
+
+			draw_activity_graphs(1, SVG_LINE_GRAPH,
+					     title1, g1_title, item_name, group,
+					     spmin + 2 * i, spmax + 2 * i, out + 2 * i, outsize + 2 * i,
+					     svg_p, record_hdr);
+			draw_activity_graphs(1, SVG_BAR_GRAPH,
+					     title2, g2_title, item_name, group,
+					     spmin + 2 * i + 1, spmax + 2 * i + 1,
+					     out + 2 * i + 1, outsize + 2 * i + 1,
+					     svg_p, record_hdr);
+		}
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display huge pages statistics in SVG.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @action	Action expected from current function.
+ * @svg_p	SVG specific parameters: Current graph number (.@graph_no),
+ * 		flag indicating that a restart record has been previously
+ * 		found (.@restart) and a pointer on a record header structure
+ * 		(.@record_hdr) containing the first stats sample.
+ * @itv		Interval of time in jiffies (only with F_MAIN action).
+ * @record_hdr	Pointer on record header of current stats sample.
+ ***************************************************************************
+ */
+__print_funct_t svg_print_huge_stats(struct activity *a, int curr, int action, struct svg_parm *svg_p,
+				     unsigned long long itv, struct record_header *record_hdr)
+{
+	struct stats_huge
+		*smc = (struct stats_huge *) a->buf[curr];
+	int group1[] = {2};
+	int group2[] = {1};
+	char *title1[] = {"Huge pages utilization (1)"};
+	char *title2[] = {"Huge pages utilization (2)"};
+	char *g1_title[] = {"~kbhugfree", "~kbhugused"};
+	char *g2_title[] = {"%hugused"};
+	static double *spmin, *spmax;
+	static char **out;
+	static int *outsize;
+	double tval;
+
+	if (action & F_BEGIN) {
+		/*
+		 * Allocate arrays that will contain the graphs data
+		 * and the min/max values.
+		 */
+		out = allocate_graph_lines(3, &outsize, &spmin, &spmax);
+	}
+
+	if (action & F_MAIN) {
+		/* Check for min/max values */
+		save_extrema(0, 1, 0, (void *) a->buf[curr], NULL,
+			     itv, spmin, spmax);
+
+		if (smc->tlhkb - smc->frhkb < *(spmin + 1)) {
+			*(spmin + 1) = smc->tlhkb - smc->frhkb;
+		}
+		if (smc->tlhkb - smc->frhkb > *(spmax + 1)) {
+			*(spmax + 1) = smc->tlhkb - smc->frhkb;
+		}
+		tval = smc->tlhkb ? SP_VALUE(smc->frhkb, smc->tlhkb, smc->tlhkb) : 0.0;
+		if (tval < *(spmin + 2)) {
+			*(spmin + 2) = tval;
+		}
+		if (tval > *(spmax + 2)) {
+			*(spmax + 2) = tval;
+		}
+
+		/* kbhugfree */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) smc->frhkb,
+			  out, outsize, svg_p->restart);
+		/* hugused */
+		lniappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			  (unsigned long) smc->tlhkb - smc->frhkb,
+			  out + 1, outsize + 1, svg_p->restart);
+		/* %hugused */
+		brappend(record_hdr->ust_time - svg_p->record_hdr->ust_time,
+			 0.0, tval,
+			 out + 2, outsize + 2, svg_p->dt);
+	}
+
+	if (action & F_END) {
+		draw_activity_graphs(1, SVG_LINE_GRAPH,
+				     title1, g1_title, NULL, group1,
+				     spmin, spmax, out, outsize, svg_p, record_hdr);
+		draw_activity_graphs(1, SVG_BAR_GRAPH,
+				     title2, g2_title, NULL, group2,
+				     spmin + 2, spmax + 2, out + 2, outsize + 2,
+				     svg_p, record_hdr);
+
+		/* Free remaining structures */
+		free_graphs(out, outsize, spmin, spmax);
+	}
+}
